#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-lib
version:              1.4.3
visibility:           public
id:                   clash-lib-1.4.3-GS2vP7VnUAyEuWWkFXmiO9
key:                  clash-lib-1.4.3-GS2vP7VnUAyEuWWkFXmiO9
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2019, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - As a library

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * The CoreHW internal language: SystemF + Letrec + Case-decomposition

    * The normalisation process that brings CoreHW in a normal form that can be
    converted to a netlist

    * Blackbox/Primitive Handling


    Front-ends (for: parsing, typecheck, etc.) are provided by separate packages:

    * <https://hackage.haskell.org/package/clash-ghc GHC/Haskell Frontend>

    * <https://github.com/christiaanb/Idris-dev Idris Frontend>


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  927427d99e034cca12ef0cc675bb2566
exposed:              True
exposed-modules:
    Clash.Annotations.BitRepresentation.ClashLib Clash.Backend
    Clash.Backend.SystemVerilog Clash.Backend.VHDL
    Clash.Backend.Verilog Clash.Core.DataCon Clash.Core.EqSolver
    Clash.Core.Evaluator.Types Clash.Core.FreeVars Clash.Core.Literal
    Clash.Core.Name Clash.Core.PartialEval
    Clash.Core.PartialEval.AsTerm Clash.Core.PartialEval.Monad
    Clash.Core.PartialEval.NormalForm Clash.Core.Pretty
    Clash.Core.Subst Clash.Core.Term Clash.Core.TermInfo
    Clash.Core.TermLiteral Clash.Core.TermLiteral.TH
    Clash.Core.Termination Clash.Core.TyCon Clash.Core.Type
    Clash.Core.TysPrim Clash.Core.Util Clash.Core.Var Clash.Core.VarEnv
    Clash.Debug Clash.Driver Clash.Driver.Manifest Clash.Driver.Types
    Clash.Edalize.Edam Clash.Netlist Clash.Netlist.BlackBox
    Clash.Netlist.BlackBox.Parser Clash.Netlist.BlackBox.Types
    Clash.Netlist.BlackBox.Util Clash.Netlist.Id
    Clash.Netlist.Id.Common Clash.Netlist.Id.Internal
    Clash.Netlist.Id.SystemVerilog Clash.Netlist.Id.VHDL
    Clash.Netlist.Id.Verilog Clash.Netlist.Types Clash.Netlist.Util
    Clash.Normalize Clash.Normalize.DEC
    Clash.Normalize.PrimitiveReductions Clash.Normalize.Strategy
    Clash.Normalize.Transformations Clash.Normalize.Types
    Clash.Normalize.Util Clash.Pretty Clash.Primitives.DSL
    Clash.Primitives.GHC.Int Clash.Primitives.GHC.Literal
    Clash.Primitives.GHC.Word Clash.Primitives.Intel.ClockGen
    Clash.Primitives.Sized.ToInteger Clash.Primitives.Sized.Vector
    Clash.Primitives.Types Clash.Primitives.Util
    Clash.Primitives.Verification Clash.Rewrite.Combinators
    Clash.Rewrite.Types Clash.Rewrite.Util Clash.Rewrite.WorkFree
    Clash.Unique Clash.Util Clash.Util.Graph Clash.Util.Interpolate
    Data.Text.Prettyprint.Doc.Extra

hidden-modules:
    Clash.Annotations.TopEntity.Extra Control.Applicative.Extra
    Data.Aeson.Extra Data.List.Extra Data.Map.Ordered.Extra
    Data.Primitive.ByteArray.Extra Data.Semigroup.Monad.Extra
    Data.Set.Ordered.Extra GHC.BasicTypes.Extra GHC.SrcLoc.Extra
    Paths_clash_lib

import-dirs:          /usr/lib/ghc-9.0.1/site-local/clash-lib-1.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/clash-lib-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/clash-lib-1.4.3
hs-libraries:         HSclash-lib-1.4.3-GS2vP7VnUAyEuWWkFXmiO9
depends:
    aeson-1.5.6.0-Hu48mgwBrEQKjw91bueUbm
    aeson-pretty-0.8.8-3OSj6xBY8p348Nh9dWt1mZ
    ansi-terminal-0.11-Ag5cePN38Me87eTiPqxHZW array-0.5.4.0
    attoparsec-0.14.1-EcyJzfZhZzx4rFmzSXlwR7 base-4.15.0.0
    base16-bytestring-1.0.1.0-2afh9UEVyJi56OJehbA0Qt binary-0.8.8.0
    bytestring-0.10.12.1 clash-prelude-1.4.3-1372dMnrHUtAXppwMwOZHy
    concurrent-supply-0.1.8-KwFWt6XwB9a5JVdvxwpXWD containers-0.6.4.1
    cryptohash-sha256-0.11.102.0-FE8p9CgRKoRHgNBR3DBqmr
    data-binary-ieee754-0.4.4-1uzt85nFoxu5Mgq2DE5oph
    data-default-0.7.1.1-9pDbF71G48YK8T0Zltgcr6 deepseq-1.4.5.0
    directory-1.3.6.1 dlist-1.0-4uSjbl72fpn9e2vwvg1nn4
    errors-2.3.0-L61cpO3OjOyLP7j03MZ5aR exceptions-0.10.4
    extra-1.7.10-IKTdTMveNU45Czd2kxoN4l filepath-1.4.2.1 ghc-9.0.1
    ghc-bignum-1.0 ghc-boot-th-9.0.1
    hashable-1.3.3.0-23uoxU4x6MLFe9vf4ULvQk
    haskell-src-meta-0.8.7-Ar8PirYthn1H4hKbxGX192
    hint-0.9.0.4-4TjNgsPZpksA67a6xnfD1d
    interpolate-0.2.1-7GbjPs8f2AK8iiK2Kfnd0
    lens-5.0.1-rlrBG3eUIE9ghmFG9oii1 mtl-2.2.2
    ordered-containers-0.2.2-HFNNhie1Aw64sPyEbOR86d
    parsers-0.12.10-9IQPJqe1YO36SVr2t53or4
    pretty-show-1.10-G4SfLXvOfw8HasEUHDrqxD
    prettyprinter-1.7.1-7rmYoMkh0xy8XND4bMZ0rp
    primitive-0.7.2.0-JNIC7nP5sETC1HdsqczlAX process-1.6.11.0
    reducers-3.12.3-ERLhw7P4sI76fOTdngbCMm template-haskell-2.17.0.0
    temporary-1.3-DoCk13Nh2D4AZEU9Ihg8GU
    terminal-size-0.3.2.1-8rLUbNor4uN6iQgtxjW6lw text-1.2.4.1
    text-show-3.9.1-9PLplsougHIAKsdjoxEd2c time-1.9.3
    transformers-0.5.6.2 trifecta-2.1.1-A46fx0TOBVBCWLL3QKmZ6P
    unordered-containers-0.2.14.0-7LMDP5QPSZY4o6Vs5H6SAe
    utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
    vector-0.12.3.1-7avVqi4S14u4vwRbDqmIKr
    vector-binary-instances-0.2.5.2-E65ikTzKOEhLrJvfyA0U7t

haddock-interfaces:   /usr/share/doc/haskell-clash-lib/html/clash-lib.haddock
haddock-html:         /usr/share/doc/haskell-clash-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

